- After each change, run `make test` to check project health (requires Docker)
- Install packages with `uv add <pkg>` or `uv add --dev <pkg>`
- Test Github CI runs cleanly with `make act`
- Avoid modifying the global Python environment or relying on globally installed packages
- Each time you commit a change, decide if something is worth adding to the changelog in the README. Keep a `dev` line for changes since the last tagged version.
- Don't bother with a dev section in the changelog if there are not dev changes outstanding
- When you bump the version number, and commit that change, be sure to tag the commit as well
- Create and publish a new release with `make publish`
- When doing a release, ask me to run `make publish` manually myself -- it requires a token
- Whenever committing, check for unstaged files first
- After changing the package version, run `uv sync` and add `uv.lock` before committing